diff --git a/examples/demo.html b/demo/index.html
similarity index 100%
rename from examples/demo.html
rename to demo/index.html
diff --git a/examples/simplified-augmentations.js b/demo/simplified-augmentations.js
similarity index 98%
rename from examples/simplified-augmentations.js
rename to demo/simplified-augmentations.js
index 3ab0f135..55514952 100644
--- a/examples/simplified-augmentations.js
+++ b/demo/simplified-augmentations.js
@@ -370,7 +370,7 @@ async function example5() {
}
/**
* Run all examples
*/
async function runExamples() {
try {
@@ -380,11 +380,11 @@ async function runExamples() {
await example4()
await example5()
- console.log('All examples completed successfully!')
+ console.log('All demo completed successfully!')
} catch (error) {
- console.error('Error running examples:', error)
+ console.error('Error running demo:', error)
}
}
// Run the examples
runExamples()
@@ -370,7 +370,7 @@ async function example5() {
}
/**
- * Run all examples
+ * Run all demo
*/
async function runExamples() {
@@ -380,11 +380,11 @@ async function runExamples() {
}
}
-// Run the examples
+// Run the demo
runExamples()